<?php
/**
 * A field type for SlideShare presentations
 *
 * @package default
 * @author Rachel Andrew
 */
class PerchFieldType_slideshare extends PerchAPI_FieldType
{
    /* ------------------------------------------------------------------- 

        You need a SlideShare API key (and secret) to use this.
        Get these from:

            http://apiexplorer.slideshare.net
        
        Once you have them, enter them below.

    */

    private $api_key = '';
    private $secret  = '';
    

    /* ------------------------------------------------------------------- */


    private $api_url = 'https://www.slideshare.net/api/2/';

    /**
     * Output the form fields for the edit page
     *
     * @param array $details 
     * @return void
     * @author Rachel Andrew
     */
    public function render_inputs($details=array())
    {
        $id = $this->Tag->input_id();
        $val = '';
        
        if (isset($details[$id]) && $details[$id]!='') {
            $json = $details[$id];
            $val  = $json['path']; 
        }else{
            $json = array();
        }

              

        $s = $this->Form->text($this->Tag->input_id(), $val);
        
        if (isset($json['slideshowID'])) {
            $s.= '<div class="preview"><img src="'.$json['thumbnail_url'].'" alt="'.PerchUtil::html($json['title'], true).'" /></div>';
        }

        if ($this->api_key=='') {
            $s.= '<p class="alert error">You need to add a SlideShare API Key to the <code>addons/fieldtypes/slideshare/slideshare.class.php</code> file.</p>';
        }
        

        return $s;
    }
    
    
    /**
     * Read in the form input, prepare data for storage in the database.
     *
     * @param string $post 
     * @param object $Item 
     * @return void
     * @author Rachel Andrew
     */
    public function get_raw($post=false, $Item=false) 
    {
        $store = array();
                
        $id = $this->Tag->id();

        if ($post===false) {
            $post = $_POST;
        }
        
        if (isset($post[$id])) {
            $this->raw_item = trim($post[$id]);
            $url = $this->raw_item;
        }
        
        if ($url) {
            $store['path'] = $url;

            $details = $this->get_details($store['path']);
        
            if ($details) {
                $store = array_merge($store, $details);
                $store['_title'] = $store['title'];
            }
        
        }
                
        return $store;
    }
    
    /**
     * Take the raw data input and return process values for templating
     *
     * @param string $raw 
     * @return void
     * @author Rachel Andrew
     */
    public function get_processed($raw=false)
    {    
        if (is_array($raw)) {
            
            $item = $raw;
                        
            if ($this->Tag->output() && $this->Tag->output()!='embed') {
                switch($this->Tag->output()) {        
                    case 'id':
                        return isset($item['slideshowID']) ? $item['slideshowID'] : false;
                        break;

                    default:
                        if (isset($item[$this->Tag->output()])) {
                            return $item[$this->Tag->output()];
                        }
                        break;
                }

                return false;
            }

            $this->processed_output_is_markup = true;
            return $item['embed'];
        }
        return $raw;
    }
    
    /**
     * Get the value to be used for searching
     *
     * @param string $raw 
     * @return void
     * @author Drew McLellan
     */
    public function get_search_text($raw=false)
    {
        if ($raw===false) $raw = $this->get_raw();
        if (!PerchUtil::count($raw)) return false;

        $out = '';

        if (isset($raw['title']))       $out .= $raw['title'];
        if (isset($raw['description'])) $out .= $raw['description'];

        return $out;
    }
    
    
    /**
     * Get information about the slideshow, passign in a URL.
     *
     * @param string $slideshareURL A URL of a deck on slideshare
     * @return array Assoc array of details
     * @author Rachel Andrew
     */
    private function get_details($slideshareURL)
    {
        
        $ts = time();
        $hash = sha1($this->secret . $ts);

        $url = $this->api_url .'get_slideshow?slideshow_url='. $slideshareURL .'&detailed=1&api_key='.$this->api_key .'&hash='.$hash .'&ts='.$ts;
        PerchUtil::debug($url);
        $ch     = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_TIMEOUT, 10);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
        $xml_string = curl_exec($ch);
        curl_close($ch);
        
        if ($xml_string) {

            PerchUtil::debug(PerchUtil::html($xml_string));
            $xml = simplexml_load_string($xml_string);
        
            
            if ($xml) {
                $out = array();
                $out['slideshowID']   = strval($xml->ID);
                $out['title']         = strval($xml->Title);
                $out['description']   = strval($xml->Description);
                $out['username']      = strval($xml->Username);
                $out['thumbnail_url'] = strval($xml->ThumbnailURL);
                $out['date']          = date('Y-m-d H:i:s', strtotime(strval($xml->Created)));
                $out['embed']         = strval(html_entity_decode($xml->Embed));
               
                return $out;
            }
        }
        
        return false;
    }


}

?>